FacilityPort
============

.. automodule:: fabrictestbed_extensions.fablib.facility_port
   :members:

.. autoclass:: fabrictestbed_extensions.fablib.facility_port.FacilityPort
   :members:
   :special-members: __init__, __str__
